Module blaxel.core.sandbox.client.models.process_response
=========================================================

Classes
-------

`ProcessResponse(command: str, completed_at: str, exit_code: int, logs: str, name: str, pid: str, started_at: str, status: blaxel.core.sandbox.client.models.process_response_status.ProcessResponseStatus, working_dir: str)`
:   Attributes:
        command (str):  Example: ls -la.
        completed_at (str):  Example: Wed, 01 Jan 2023 12:01:00 GMT.
        exit_code (int):
        logs (str):  Example: logs output.
        name (str):  Example: my-process.
        pid (str):  Example: 1234.
        started_at (str):  Example: Wed, 01 Jan 2023 12:00:00 GMT.
        status (ProcessResponseStatus):  Example: running.
        working_dir (str):  Example: /home/user.
    
    Method generated by attrs for class ProcessResponse.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `command: str`
    :

    `completed_at: str`
    :

    `exit_code: int`
    :

    `logs: str`
    :

    `name: str`
    :

    `pid: str`
    :

    `started_at: str`
    :

    `status: blaxel.core.sandbox.client.models.process_response_status.ProcessResponseStatus`
    :

    `working_dir: str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :